==> nextcloud-12.0.2.tgz: nextcloud/apps/serverinfo/l10n/el.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Μέσος όρος φόρτωσης",
    "Last minute" : "Τελευταίο λεπτό",
    "Memory info not available" : "Η πληροφορία μνήμης δεν είναι διαθέσιμη",
    "Total" : "Σύνολο",
    "Current usage" : "Τρέχουσα χρήση",
    "Users" : "Χρήστες",
    "Groups" : "Ομάδες",
    "Links" : "Σύνδεσμοι",
    "Federated sent" : "Το Federated απεστάλη",
    "Federated received" : "Λήφθηκε το Federated",
    "Last 24 hours" : "Τελευταίες 24 ώρες",
    "Last 1 hour" : "Τελευταία 1 ώρα",
    "Last 5 mins" : "Τελευταία 5 λεπτά",
    "Monitoring" : "Παρακολούθηση",
    "CPU load" : "Φόρτωση CPU",
    "Memory usage" : "Χρήση μνήμης",
    "Active users" : "Ενεργοί χρήστες",
    "Shares" : "Κοινόχρηστοι φάκελοι",
    "Storage" : "Αποθηκευτικός χώρος",
    "Users:" : "Χρήστες:",
    "Files:" : "Αρχεία:",
    "PHP" : "PHP",
    "Version:" : "Έκδοση:",
    "Memory Limit:" : "Όριο μνήμης:",
    "Max Execution Time:" : "Μέγιστος χρόνος εκτέλεσης:",
    "Upload max size:" : "Μέγιστο μέγεθος μεταφόρτωσης:",
    "Database" : "Βάση δεδομένων",
    "Type:" : "Τύπος:",
    "Size:" : "Μέγεθος:",
    "External monitoring tool" : "Εξωτερικό εργαλείο παρακολούθησης",
    "You can connect an external monitoring tool by using this end point: " : "Μπορείτε να συνδεθείτε στο εργαλείο εξωτερικής παρακολούθησης με την χρήση αυτού του τελικού σημείου:",
    "Server info" : "Πληροφορίες διακομιστή",
    "You can connect a external monitoring tool by using this end point: " : "Μπορείτε να συνδέσετε ένα εξωτερικό εργαλείο παρακολούθησης χρησιμοποιώντας αυτό το τελικό σημείο"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/serverinfo/l10n/el.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Μέσος όρος φόρτωσης",
    "Last minute" : "Τελευταίο λεπτό",
    "Memory info not available" : "Η πληροφορία μνήμης δεν είναι διαθέσιμη",
    "Total" : "Σύνολο",
    "Current usage" : "Τρέχουσα χρήση",
    "Users" : "Χρήστες",
    "Groups" : "Ομάδες",
    "Links" : "Σύνδεσμοι",
    "Federated sent" : "Το Federated απεστάλη",
    "Federated received" : "Λήφθηκε το Federated",
    "Last 24 hours" : "Τελευταίες 24 ώρες",
    "Last 1 hour" : "Τελευταία 1 ώρα",
    "Last 5 mins" : "Τελευταία 5 λεπτά",
    "Copy" : "Αντιγραφή",
    "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
    "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C.",
    "Monitoring" : "Παρακολούθηση",
    "CPU load" : "Φόρτωση CPU",
    "Memory usage" : "Χρήση μνήμης",
    "Active users" : "Ενεργοί χρήστες",
    "Shares" : "Κοινόχρηστοι φάκελοι",
    "Storage" : "Αποθηκευτικός χώρος",
    "Users:" : "Χρήστες:",
    "Files:" : "Αρχεία:",
    "Version:" : "Έκδοση:",
    "PHP" : "PHP",
    "Memory Limit:" : "Όριο μνήμης:",
    "Max Execution Time:" : "Μέγιστος χρόνος εκτέλεσης:",
    "Upload max size:" : "Μέγιστο μέγεθος μεταφόρτωσης:",
    "Database" : "Βάση δεδομένων",
    "Type:" : "Τύπος:",
    "Size:" : "Μέγεθος:",
    "External monitoring tool" : "Εξωτερικό εργαλείο παρακολούθησης",
    "You can connect an external monitoring tool by using this end point: " : "Μπορείτε να συνδεθείτε στο εργαλείο εξωτερικής παρακολούθησης με την χρήση αυτού του τελικού σημείου:"
},
"nplurals=2; plural=(n != 1);");
